@@ -1,23 +1,13 @@
-from .terminal import (
-    run_command,
-    check_install,
-    get_installdir,
-    get_userhome,
-    get_user,
-    which,
-    confirm_action,
-    confirm_uninstall,
-)
+from .docs import get_docstring
 from .fileio import (
-    can_be_deleted,
     copyfile,
     creation_date,
     get_file_hash,
     get_tmpdir,
     get_tmpfile,
+    list_modules,
     mkdir_p,
     mkdirp,
-    rmdir_to_base,
     print_json,
     read_file,
     read_json,
@@ -25,3 +15,14 @@ from .fileio import (
     write_file,
     write_json,
 )
+from .inspect import dynamic_import
+from .terminal import (
+    check_install,
+    confirm_action,
+    confirm_uninstall,
+    get_installdir,
+    get_user,
+    get_userhome,
+    run_command,
+    which,
+)
